"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const csap_axios_1 = require("csap-axios");
const auth_1 = require("./auth");
// create an axios instance
csap_axios_1.default.defaults.withCredentials = true;
const service = csap_axios_1.default.create({
    // withCredentials: true, // send cookies when cross-domain requests
    timeout: 5000 // request timeout
});
// request interceptor
service.interceptors.request.use(config => {
    let token = null;
    if ((token = (0, auth_1.getToken)()) != null && config.headers.Authorization == null) {
        // let each request carry token
        // ['X-Token'] is a custom headers key
        // please modify it according to the actual situation
        config.headers['Authorization'] = token;
    }
    return config;
}, error => {
    // do something with request error
    return Promise.reject(error);
});
// response interceptor
service.interceptors.response.use(response => {
    const res = response.data;
    // if the custom code is not 20000, it is judged as an error.
    if (res.code != 0) {
        console.error(res.message || 'Error');
        return Promise.reject(new Error(res.message || 'Error'));
    }
    else {
        return res;
    }
}, error => {
    if (error.response.status == 401) {
        error.message = "用户失效,请重新登录!";
        localStorage.clear();
    }
    console.error(error.message || 'Error');
    return Promise.reject(error);
});
exports.default = service;
