"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DefaultHttpRequest = void 0;
const BeanFactory_1 = require("../BeanFactory");
const request_1 = require("../request");
class DefaultHttpRequest {
    constructor() {
    }
    /**
     * GET 请求
     * @param data
     * @param method_name
     * @returns {AxiosPromise}
     */
    get(data) {
        data.method = BeanFactory_1.HttpMethod.GET;
        return this.execute(data);
    }
    /**
     * post请求
     * @param data
     * @param baseFrameWorkParam
     * @returns {AxiosPromise}
     */
    post(data) {
        data.method = BeanFactory_1.HttpMethod.POST;
        return this.execute(data);
    }
    /**
     * put修改操作
     * @param data
     * @param baseFrameWorkParam
     * @returns {AxiosPromise}
     */
    put(data) {
        data.method = BeanFactory_1.HttpMethod.PUT;
        return this.execute(data);
    }
    /**
     * delete请求
     * @param data
     * @param baseFrameWorkParam
     * @returns {AxiosPromise}
     */
    delete(data) {
        data.method = BeanFactory_1.HttpMethod.DELETE;
        return this.execute(data);
    }
    /**
     * patch 请求
     * @param data
     * @param baseFrameWorkParam
     * @returns {AxiosPromise}
     */
    patch(data) {
        data.method = BeanFactory_1.HttpMethod.PATCH;
        return this.execute(data);
    }
    /**
     * options请求
     *
     * @param data
     * @param baseFrameWorkParam
     * @returns {AxiosPromise}
     */
    options(data) {
        data.method = BeanFactory_1.HttpMethod.OPTIONS;
        return this.execute(data);
    }
    /**
     * 执行请求
     * @param method
     * @param data
     * @param baseFrameWorkParam
     * @returns {AxiosPromise}
     */
    execute(data) {
        let h = data.getHeaders();
        return this.getAxiosInstance().request({
            baseURL: data.url,
            url: data.path,
            params: data.dataType == BeanFactory_1.DataType.DEFAULT ? data.data : null,
            data: (data.dataType == BeanFactory_1.DataType.JSON || data.dataType == BeanFactory_1.DataType.FORMAT_DATA) ? data.data : null,
            method: data.method,
            headers: h == null || Object.keys(h).length == 0 ? null : h
        });
    }
    getAxiosInstance() {
        return request_1.default;
    }
}
exports.DefaultHttpRequest = DefaultHttpRequest;
